@@ -6,6 +6,7 @@ use fuzzy_matcher::{
     FuzzyMatcher,
 };
 use std::borrow::Cow;
+use std::cell::UnsafeCell;
 use std::cmp::{Ordering, PartialOrd};
 use tokio::task::spawn_blocking;
 
@@ -69,10 +70,15 @@ impl MyRaw<*const str> {
     fn new(s: &str) -> MyRaw<*const str> {
         MyRaw(s as *const str)
     }
-    unsafe fn get(&self) -> &str {
+    unsafe fn as_str(&self) -> &str {
         &*self.0
     }
 }
+impl<T: Copy> MyRaw<T> {
+    fn get(&self) -> T {
+        self.0
+    }
+}
 
 enum MyCow {
     Borrowed(MyRaw<*const str>),
@@ -87,7 +93,7 @@ impl MyCow {
     }
     unsafe fn get(&self) -> &str {
         match self {
-            MyCow::Borrowed(s) => s.get(),
+            MyCow::Borrowed(s) => s.as_str(),
             MyCow::Owned(s) => &*s,
         }
     }
@@ -105,10 +111,14 @@ impl FuzzScore {
 }
 impl PartialOrd for FuzzScore {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        match self.score.cmp(&other.score) {
-            Ordering::Equal => Some(other.len.cmp(&self.len)),
-            res @ _ => Some(res),
-        }
+        Some(
+            if (self.score - other.score).abs() < 2 && self.len != other.len {
+                // 吃掉「正常排序就命中」的差異
+                other.len.cmp(&self.len)
+            } else {
+                self.score.cmp(&other.score)
+            },
+        )
     }
 }
 impl Ord for FuzzScore {
@@ -132,7 +142,9 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
     multifuzz_ratio: Option<i64>,
 ) -> Result<Option<FuzzResult<T>>> {
     let raw_name = MyRaw::new(name);
-    let mut data_vec: Vec<_> = iter.map(|t| (FuzzScore::default(), t)).collect();
+    let mut data_vec: Vec<_> = iter
+        .map(|t| (UnsafeCell::new(FuzzScore::default()), t))
+        .collect();
     let sep = MyRaw::new(sep);
     let has_ratio = multifuzz_ratio.is_some();
 
@@ -144,14 +156,14 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
 
     let score_fut = data_vec.iter_mut().map(|(score, data)| {
         let key = MyCow::new(data.fuzz_key());
-        let score_ptr = MyRaw(score as *mut _);
+        let score_ptr = MyRaw(score.get());
         spawn_blocking(move || {
             // SAFTY: 等等就會 join，故這個函式 await 完之前都不可能釋放這些字串
             let key = unsafe { key.get() };
             let score = my_fuzz(
                 key,
-                unsafe { raw_name.get() },
-                unsafe { sep.get() },
+                unsafe { raw_name.as_str() },
+                unsafe { sep.as_str() },
                 !has_ratio,
             );
 
@@ -160,7 +172,7 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
                 // SAFETY: 怎麼可能有多個人持有同個元素的分數
                 assert_ne!(len, 0);
                 unsafe {
-                    *score_ptr.0 = FuzzScore { score, len };
+                    *score_ptr.get() = FuzzScore { score, len };
                 }
             }
         })
@@ -169,8 +181,8 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
     join_all(score_fut).await;
     // NOTE: 算分數就別平行做了，不然要搞原子性，可能得不償失
     let best_score = data_vec
-        .iter()
-        .map(|(score, _)| *score)
+        .iter_mut()
+        .map(|(score, _)| *score.get_mut())
         .max()
         .unwrap_or_default();
 
@@ -186,6 +198,7 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
     let mut multifuzz_vec = vec![];
     let mut secondary_multifuzz_vec = vec![];
     for (score, data) in data_vec.into_iter() {
+        let score = score.into_inner();
         if score == best_score && ans.is_none() {
             ans = Some(data);
         } else if is_multifuzz(score.score, best_score.score) {
@@ -394,12 +407,12 @@ mod test {
 
         let res = do_fuzz("ab", &vec).await.unwrap();
         let (ans, v) = extract_multifuzz(res);
-        assert_eq!(ans, "a:b");
+        assert_eq!(ans, "a:b"); // 正常排序就命中
         assert_eq!(v, vec!["a:b", "b:a"]);
 
         let res = do_fuzz("ba", &vec).await.unwrap();
         let (ans, v) = extract_multifuzz(res);
-        assert_eq!(ans, "b:a");
+        assert_eq!(ans, "b:a"); // 正常排序就命中
         assert_eq!(v, vec!["a:b", "b:a"]);
 
         let res = do_fuzz("ca", &vec).await.unwrap();
@@ -409,6 +422,12 @@ mod test {
         let (ans, v) = extract_multifuzz(res);
         assert_eq!(ans, "a:c"); // 真的同分，只好以順序決定了
         assert_eq!(v, vec!["a:b", "a:c", "b:a"]);
+
+        let vec = vec!["a:b:c", "c:a"];
+        let res = do_fuzz("a", &vec).await.unwrap();
+        let (ans, v) = extract_multifuzz(res);
+        assert_eq!(ans, "c:a");
+        assert_eq!(v, vec!["a:b:c", "c:a"]);
     }
     #[test]
     fn test_reorder() {
