@@ -24,7 +24,7 @@ fn test_tags() {
     )
     .unwrap();
     run!("tesjs").expect_err("標籤沒有篩選掉不該出現的腳本！");
-    assert_eq!(MSG_JS, run!("-f super_tag -").unwrap());
+    assert_eq!(MSG_JS, run!("-s super_tag -").unwrap());
 
     assert_eq!(MSG, run!(".1").expect("標籤篩選把舊的腳本搞爛了！"));
 
@@ -61,7 +61,7 @@ fn test_mv_cp() {
     run!("mv 1 -t +hide").unwrap();
     run!("-").expect_err("用 mv 修改標籤失敗？");
 
-    run!("cp -f hide 1 -t +cp .2").unwrap();
+    run!("cp -s hide 1 -t +cp .2").unwrap();
     let mut res: Vec<_> = run!(".2!")
         .unwrap()
         .split(' ')
@@ -70,7 +70,7 @@ fn test_mv_cp() {
     res.sort();
     assert_eq!(vec!["cp", "hide", "test2"], res);
 
-    run!("cp -f hide - -t only .3").unwrap();
+    run!("cp -s hide - -t only .3").unwrap();
     let res: Vec<_> = run!("!")
         .unwrap()
         .split(' ')
@@ -130,7 +130,7 @@ fn test_edit_same_name() {
     run!("e i-am-hidden -t hide | echo \"{}\"", MSG).unwrap();
     run!("-").expect_err("執行了隱藏的腳本？？");
     run!("e i-am-hidden yo | echo I'm screwed QQ").expect_err("竟然能編輯撞名的腳本？");
-    assert_eq!(MSG, run!("-f hide -").unwrap(), "腳本被撞名的編輯搞爛了？");
+    assert_eq!(MSG, run!("-s hide -").unwrap(), "腳本被撞名的編輯搞爛了？");
 }
 
 #[test]
@@ -139,7 +139,7 @@ fn test_edit_append() {
 
     run!("e -t test test | echo 第一行").unwrap();
     run!("e - | echo 第二行\necho 第三行").unwrap();
-    assert_eq!("第一行\n第二行\n第三行", run!("-f test -").unwrap());
+    assert_eq!("第一行\n第二行\n第三行", run!("-s test -").unwrap());
 }
 
 #[test]
@@ -153,17 +153,17 @@ fn test_edit_with_tag() {
     run!("tags innate").unwrap();
 
     run!("e test1 -t tag2 | echo \"{}\"", msg(1)).unwrap();
-    run!("-f innate -").expect_err("吃到了不該吃的標籤！");
-    assert_eq!(msg(1), run!("-f tag2 -").unwrap());
+    run!("-s innate -").expect_err("吃到了不該吃的標籤！");
+    assert_eq!(msg(1), run!("-s tag2 -").unwrap());
 
     run!("e test2 -t +tag2,tag3 | echo \"{}\"", msg(2)).unwrap();
-    assert_eq!(msg(2), run!("-f innate -").unwrap());
-    assert_eq!(msg(2), run!("-f tag2 -").unwrap());
-    assert_eq!(msg(2), run!("-f tag3 -").unwrap());
+    assert_eq!(msg(2), run!("-s innate -").unwrap());
+    assert_eq!(msg(2), run!("-s tag2 -").unwrap());
+    assert_eq!(msg(2), run!("-s tag3 -").unwrap());
 }
 
 #[test]
-fn test_multi_filter() {
+fn test_multi_select() {
     let _g = setup();
     run!("e nobody | echo \"{}\"", MSG).unwrap();
     run!("e -t test,pin test-pin | echo \"{}\"", MSG).unwrap();
@@ -199,15 +199,15 @@ fn test_rm() {
     run!("test/ya").expect_err("未能被刪除掉");
     run!(".1").expect_err("未能被刪除掉");
     run!("-a test/ya").expect_err("被刪除掉的腳本竟能用 `-a` 找回來");
-    assert_eq!(MSG, run!("-f removed test").unwrap());
+    assert_eq!(MSG, run!("-s remove test").unwrap());
     assert_eq!(
         MSG,
-        run!("-f test-tag test").expect("刪除沒有保留本來的標籤？")
+        run!("-s test-tag test").expect("刪除沒有保留本來的標籤？")
     );
 
     assert_eq!(
         "你匿",
-        run!("-f removed,^test-tag -").expect("就算是匿名腳本也不該真的被刪掉！")
+        run!("-s remove,^test-tag -").expect("就算是匿名腳本也不該真的被刪掉！")
     );
 
     assert_eq!("矻立不搖", run!("longlive").unwrap());
@@ -218,16 +218,16 @@ fn test_rm() {
     run!("mysuper-test").expect_err("未能被刪除掉");
     assert_eq!(
         "不要刪我 QmmmmQ",
-        run!("-f removed my/namespace/super-test").unwrap()
+        run!("-s remove my/namespace/super-test").unwrap()
     );
 
     assert_eq!("矻立不搖", run!("longlive").unwrap());
 
     assert!(check_exist(&["longlive.sh"]));
-    run!("rm * -f all --purge").expect("未能消滅掉一切");
+    run!("rm * -s all --purge").expect("未能消滅掉一切");
 
     assert!(!check_exist(&["longlive.sh"]));
-    run!("-f all which").expect_err("沒有確實消滅掉一切");
+    run!("-s all which").expect_err("沒有確實消滅掉一切");
 
     // NOTE: ---- 測試用 ! 來刪除 ----
     run!("e -t hide hidden | echo 隱藏腳本，請用 ! 刪除我").unwrap();
@@ -256,7 +256,7 @@ fn test_append_tags() {
     run!("tags global,test").unwrap();
 
     pub fn assert_tags<const N: usize>(script: &ScriptTest, tags: [&str; N]) {
-        let res = script.filter("-a").run("").unwrap();
+        let res = script.select("-a").run("").unwrap();
         let mut actual_tags: Vec<_> = res.split(' ').filter(|s| !s.is_empty()).collect();
         actual_tags.sort();
         let mut expected_tags: Vec<_> = tags.iter().map(|s| *s).collect();
@@ -271,7 +271,7 @@ fn test_append_tags() {
     no_append_test.assert_not_exist(None, None);
     assert_tags(&no_append_test, ["no-append"]);
 
-    run!("mv -f no-append no-append-test -t +eventually-append").unwrap();
+    run!("mv -s no-append no-append-test -t +eventually-append").unwrap();
 
     assert_tags(&no_append_test, ["no-append", "eventually-append"]);
     assert_tags(&append_test, ["global", "test", "append"]);
@@ -299,7 +299,7 @@ fn test_bang() {
     run!("e -t hide hidden_second | echo 第二").unwrap();
     run!("e -t hide hidden_third | echo 第三").unwrap();
     run!("cp firs! fourth").unwrap();
-    run!("mv -f tag4 four! -t all").unwrap();
+    run!("mv -s tag4 four! -t all").unwrap();
 
     run!("first").expect_err("執行了隱藏的腳本？？");
     assert_eq!(first_file.to_string_lossy(), run!("firt!").unwrap());
@@ -338,7 +338,7 @@ fn test_redirect() {
 }
 
 #[test]
-fn test_mandatory_filter() {
+fn test_mandatory_select() {
     let _g = setup();
     let t1 = ScriptTest::new("prj1/t", Some("prj1"), None);
     let t2 = ScriptTest::new("prj2/t", Some("prj2"), None);
@@ -347,18 +347,18 @@ fn test_mandatory_filter() {
     let t5 = ScriptTest::new("hide/prj2/src/t", Some("hide,prj2,src"), None);
 
     assert_ls(vec![&t1, &t2, &t3, &t4], None, None);
-    assert_ls(Vec::<String>::new(), None, Some("-f all!"));
+    assert_ls(Vec::<String>::new(), None, Some("-s all!"));
     // NOTE: 順便測試在參數上帶多個篩選器
-    assert_ls(vec![&t3, &t4], None, Some("-f +src!"));
-    assert_ls(vec![&t3, &t4], None, Some("-f +src! -f +prj1")); // +prj1 非強制，不影響
-    assert_ls(vec![&t3], None, Some("-f +src! -f +prj1!")); // +prj1! 為強制，會影響
+    assert_ls(vec![&t3, &t4], None, Some("-s +src!"));
+    assert_ls(vec![&t3, &t4], None, Some("-s +src! -s +prj1")); // +prj1 非強制，不影響
+    assert_ls(vec![&t3], None, Some("-s +src! -s +prj1!")); // +prj1! 為強制，會影響
 
     run!("tags +prj1").unwrap();
     assert_ls(vec![&t1, &t3], None, None);
     assert_ls(vec![&t3, &t4, &t5], Some("src"), None);
     assert_ls(vec![&t1, &t3, &t4], Some("+src"), None);
     assert_ls(vec![&t3], Some("+src!"), None);
-    assert_ls(vec![&t4, &t5], None, Some("-f all -f +src! -f +prj2!"));
+    assert_ls(vec![&t4, &t5], None, Some("-s all -s +src! -s +prj2!"));
 }
 
 #[test]
